==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/AcceptTransitGatewayMulticastDomainAssociationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AcceptTransitGatewayMulticastDomainAssociationsResponse(
    associations: Option[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse = {
    import AcceptTransitGatewayMulticastDomainAssociationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
      .builder()
      .optionallyWith(associations.map(value => value.buildAwsValue()))(
        _.associations
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
      .wrap(buildAwsValue())
}
object AcceptTransitGatewayMulticastDomainAssociationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse =
      zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse(
        associations.map(value => value.asEditable)
      )
    def associations: Option[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ]
    def getAssociations: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = AwsError.unwrapOptionField("associations", associations)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
  ) extends zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse.ReadOnly {
    override val associations: Option[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = scala
      .Option(impl.associations())
      .map(value =>
        zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
  ): zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/AcceptTransitGatewayMulticastDomainAssociationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AcceptTransitGatewayMulticastDomainAssociationsResponse(
    associations: Optional[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse = {
    import AcceptTransitGatewayMulticastDomainAssociationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
      .builder()
      .optionallyWith(associations.map(value => value.buildAwsValue()))(
        _.associations
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
      .wrap(buildAwsValue())
}
object AcceptTransitGatewayMulticastDomainAssociationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse =
      zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse(
        associations.map(value => value.asEditable)
      )
    def associations: Optional[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ]
    def getAssociations: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = AwsError.unwrapOptionField("associations", associations)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
  ) extends zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse.ReadOnly {
    override val associations: Optional[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.associations())
      .map(value =>
        zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse
  ): zio.aws.ec2.model.AcceptTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    new Wrapper(impl)
}
